"""A collection of useful tools

This module includes some personal collection of useful tools.
It is not designed for production usage. Use it at your own risk.
"""
from . import ysdlog

__version__ = "0.1.0"
__all__ = ["ysdlog"]
